==> v1.0.0.20190301_beta.tar.gz: fastadmin/application/admin/lang/zh-cn/dashboard.php <==
<?php

return [
    'Custom'                  => '自定义',
    'Pid'                     => '父ID',
    'Type'                    => '栏目类型',
    'Image'                   => '图片',
    'Total user'              => '总会员数',
    'Total view'              => '总访问数',
    'Total order'             => '总订单数',
    'Total order amount'      => '总金额',
    'Today user signup'       => '今日注册',
    'Today user login'        => '今日登录',
    'Today order'             => '今日订单',
    'Unsettle order'          => '未处理订单',
    'Seven dnu'               => '七日新增',
    'Seven dau'               => '七日活跃',
    'Custom zone'             => '这里是你的自定义数据',
    'Sales'                   => '成交数',
    'Orders'                  => '订单数',
    'Real time'               => '实时',
    'Category count'          => '分类统计',
    'Category count tips'     => '当前分类总记录数',
    'Attachment count'        => '附件统计',
    'Attachment count tips'   => '当前上传的附件数量',
    'Article count'           => '文章统计',
    'News count'              => '新闻统计',
    'Comment count'           => '评论次数',
    'Like count'              => '点赞次数',
    'Recent news'             => '最新新闻',
    'Recent discussion'       => '最新发贴',
    'Server info'             => '服务器信息',
    'PHP version'             => 'PHP版本',
    'Fastadmin version'       => 'FastAdmin版本',
    'Fastadmin addon version' => 'FastAdmin插件版本',
    'Sapi name'               => '运行方式',
    'Debug mode'              => '调试模式',
    'Software'                => '环境信息',
    'Upload mode'             => '上传模式',
    'Upload url'              => '上传URL',
    'Upload cdn url'          => '上传CDN',
    'Cdn url'                 => '静态资源CDN',
    'Timezone'                => '时区',
    'Language'                => '语言',
    'Security tips'           => '<i class="fa fa-warning"></i> 安全提示：你正在使用默认的后台登录入口，为了你的网站安全，建议你修改后台登录入口，<a href="https://forum.fastadmin.net/thread/7640" target="_blank">点击查看修改方法</a>',
];

==> v1.0.0.20190510_beta.tar.gz: fastadmin/application/admin/lang/zh-cn/dashboard.php <==
<?php

return [
    'Custom'                  => '自定义',
    'Pid'                     => '父ID',
    'Type'                    => '栏目类型',
    'Image'                   => '图片',
    'Total user'              => '总会员数',
    'Total view'              => '总访问数',
    'Total order'             => '总订单数',
    'Total order amount'      => '总金额',
    'Today user signup'       => '今日注册',
    'Today user login'        => '今日登录',
    'Today order'             => '今日订单',
    'Unsettle order'          => '未处理订单',
    'Seven dnu'               => '七日新增',
    'Seven dau'               => '七日活跃',
    'Custom zone'             => '这里是你的自定义数据',
    'Sales'                   => '成交数',
    'Orders'                  => '订单数',
    'Real time'               => '实时',
    'Category count'          => '分类统计',
    'Category count tips'     => '当前分类总记录数',
    'Attachment count'        => '附件统计',
    'Attachment count tips'   => '当前上传的附件数量',
    'Article count'           => '文章统计',
    'News count'              => '新闻统计',
    'Comment count'           => '评论次数',
    'Like count'              => '点赞次数',
    'Recent news'             => '最新新闻',
    'Recent discussion'       => '最新发贴',
    'Server info'             => '服务器信息',
    'PHP version'             => 'PHP版本',
    'Fastadmin version'       => '主框架版本',
    'Fastadmin addon version' => '插件版本',
    'Thinkphp version'        => 'ThinkPHP版本',
    'Sapi name'               => '运行方式',
    'Debug mode'              => '调试模式',
    'Software'                => '环境信息',
    'Upload mode'             => '上传模式',
    'Upload url'              => '上传URL',
    'Upload cdn url'          => '上传CDN',
    'Cdn url'                 => '静态资源CDN',
    'Timezone'                => '时区',
    'Language'                => '语言',
    'View more'               => '查看更多',
    'Security tips'           => '<i class="fa fa-warning"></i> 安全提示：你正在使用默认的后台登录入口，为了你的网站安全，建议你修改后台登录入口，<a href="https://forum.fastadmin.net/thread/7640" target="_blank">点击查看修改方法</a>',
];
